/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef GEOCHART_H_
#define GEOCHART_H_

#include <string>

class GeoChart
{
public:
	enum Type_enum {
		TYPE_SECTIONAL,
		TYPE_TAC,
		TYPE_FLYWAY
	};

	GeoChart();

	void SetFileName(std::string FileName);
	std::string GetFileName();
	void SetName(std::string Name);
	std::string GetName();
	void SetBounding(double North, double East, double South, double West);
	double GetNorthBounding();
	double GetEastBounding();
	double GetSouthBounding();
	double GetWestBounding();
	void SetGeoReferenced(bool GeoReferenced);
	bool GetGeoReferenced();
	void SetType(Type_enum);
	Type_enum GetType();
	bool MakeBinary(struct GeoChart_Binary_struct *BinaryData);
	void SetFromBinary(struct GeoChart_Binary_struct *BinaryData);

private:
	std::string FileName;
	std::string Name;
	double EastBounding,WestBounding,NorthBounding,SouthBounding;
	bool GeoReferenced;
	enum Type_enum Type;
};

/* Increment the version when the structure changes */
#define GEOCHART_BINARY_STRUCT_VER 1
#ifdef WIN32
#pragma pack(1)
#endif
struct GeoChart_Binary_struct {
	char FileName[50];
	char Name[50];
	int32_t NorthBoundingx1000000,EastBoundingx1000000,SouthBoundingx1000000,WestBoundingx1000000;
	uint8_t GeoReferenced;
	uint8_t Type;
}
#ifndef WIN32
        __attribute__ ((packed))
#endif
;
#ifdef WIN32
#pragma pack()
#endif


#endif /*GEOCHART_H_*/
