/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef NAVAID_H_
#define NAVAID_H_

#include <stdint.h>
#include "Waypoint.h"
#include "Frequency.h"

class NavAid : public Waypoint
{
public:
	enum Type_enum {
		TYPE_VOR,
		TYPE_NDB,
		TYPE_ILS,
		TYPE_LOCALIZER
	};

	NavAid();
	virtual ~NavAid();

	virtual enum Type_enum GetType()=0;
	Frequency *GetFreq();
	void SetFreq(Frequency *NewFreq);
	double GetDeclination();	/* 
								 * Appears to be the magnetic variation it was calibrated to
								 * Positive=East, Negative=West
								 * */
	virtual bool ParseNFD(std::string Line);
	bool MakeBinary(struct NavAid_Binary_struct *BinaryData);
	void SetFromBinary(struct NavAid_Binary_struct *BinaryData);

protected:
	Frequency Freq;
	double Declination;
};

class VOR: public NavAid
{
public:
	VOR();
	enum NavAid::Type_enum GetType();
	bool ParseNFD(std::string Line);
	bool ParseXPlane810(std::string *Line);
};

class NDB: public NavAid
{
public:
	NDB();
	enum NavAid::Type_enum GetType();
	bool ParseNFD(std::string Line);
	bool ParseXPlane810(std::string *Line);
};

class ILS: public NavAid
{
public:
	ILS();
	enum NavAid::Type_enum GetType();
	bool ParseXPlane810(std::string *Line);
};

class Localizer: public NavAid
{
public:
	Localizer();
	enum NavAid::Type_enum GetType();
	bool ParseXPlane810(std::string *Line);
};

/* Increment the version when the structure changes */
#define NAVAID_BINARY_STRUCT_VER 1
#ifdef WIN32
#pragma pack(1)
#endif
struct NavAid_Binary_struct {
	char ID[16];
	char Name[50];
	int32_t Lonx1000000,Latx1000000,Declinationx100;
	uint8_t Type;
}
#ifndef WIN32
        __attribute__ ((packed))
#endif
;
#ifdef WIN32
#pragma pack()
#endif

#endif /*NAVAID_H_*/
